@@ -402,6 +402,14 @@ sub param # (param)
 	}
 }
 
+# Method: params
+#
+#      Get the CGI parameters
+#
+# Returns:
+#
+#      array ref - containing the CGI parameters
+#
 sub params
 {
 	my $self = shift;
@@ -425,6 +433,14 @@ sub cgi
 	return $self->{cgi};
 }
 
+# Method: domain
+#
+#    Get the gettext domain for this CGI
+#
+# Returns:
+#
+#    String - containing the gettext domain
+#
 sub domain
 {
 	my $self = shift;
@@ -743,16 +759,29 @@ sub masonParameters
 
 # Method: upload
 #
-# Uploads a file from the client computer. The file is place in
-#  the tmp directory 
+#  Upload a file from the client computer. The file is place in
+#  the tmp directory (/tmp)
 #
 #
-# Parameters: $uploadParam - CGI parameter which contains the path to the file
-#   which will be uploaded. Usually is obtained from a HTML file input
+# Parameters:
+#
+#   uploadParam - String CGI parameter name which contains the path to the
+#   file which will be uploaded. It is usually obtained from a HTML
+#   file input
 #
 # Returns:
-#   the path of the uploaded file
-# 
+#
+#   String - the path of the uploaded file
+#
+# Exceptions:
+#
+#   <EBox::Exceptions::Internal> - thrown if an error has happened
+#   within the CGI or it is impossible to read the upload file or the
+#   parameter does not pass on the request
+#
+#   <EBox::Exceptions::External> - thrown if there is no file to
+#   upload or cannot create the temporally file
+#
 sub upload
 {
   my ($self, $uploadParam) = @_;
@@ -764,12 +793,12 @@ sub upload
     if ($self->cgi->cgi_error) {
       throw EBox::Exceptions::Internal('Upload error: ' . $self->cgi->cgi_error);
     }
-
-    return undef;
+    throw EBox::Exceptions::Internal("The upload parameter $uploadParam does not "
+                                     . 'pass on HTTP request');
   }
 
   # get upload contents file handle
-  my $UPLOAD_FH = $self->cgi->upload($uploadParam);    
+  my $UPLOAD_FH = $self->cgi->upload($uploadParam);
   if (not $UPLOAD_FH) {
     throw EBox::Exceptions::External( __('Invalid uploaded file.'));
   }
@@ -809,5 +838,53 @@ sub upload
   return $filename;
 }
 
+# Method: setMenuNamespace
+#
+# 	Set the menu namespace to help the menu code to find out
+# 	within which namespace this cgi is running.
+#
+# 	Note that, this is useful only if you are using base CGIs
+# 	in modules different to ebox base. If you do not use this,
+# 	the namespace used will be the one the base cgi belongs to.
+#
+# Parameters:
+# 
+# 	(POSITIONAL)
+# 	namespace - string represeting the namespace in URL format. Example:
+# 			"EBox/Network"
+#
+sub setMenuNamespace
+{
+	my ($self, $namespace) = @_;
+	
+	$self->{'menuNamespace'} = $namespace;
+
+}
+
+# Method: menuNamespace
+#
+# 	Return menu namespace to help the menu code to find out
+# 	within which namespace this cgi is running.
+#
+# 	Note that, this is useful only if you are using base CGIs
+# 	in modules different to ebox base. If you do not use this,
+# 	the namespace used will be the one the base cgi belongs to.
+#
+# Returns:
+#
+# 	namespace - string represeting the namespace in URL format. Example:
+# 			"EBox/Network"
+#
+sub menuNamespace
+{
+	my ($self) = @_;
+	
+	if (exists $self->{'menuNamespace'}) {
+		return $self->{'menuNamespace'};
+	} else {
+		return $self->{'url'};
+	}
+
+}
 
 1;
